==> nextcloud-22.2.10.tgz: nextcloud/apps/password_policy/l10n/tr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Parolanın süresi dolmuş. Lütfen sıfırlamak için parolamı unuttum yöntemini kullanın",
    "Password must not have been used recently before." : "Parola son kullandığınız parolalardan farklı olmalıdır.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Yazdığınız parola sık kullanılan 1.000.000 parola içinde. Lütfen eşsiz bir parola seçin.",
    "Password is present in compromised password list. Please choose a different password." : "Yazdığınız parola bilinen parolalar listesinde. Lütfen başka bir parola seçin.",
    "Password needs to be at least %s characters long." : "Parola en az %s karakter uzunluğunda olmalıdır.",
    "Password needs to contain at least one numeric character." : "Parolada en az bir rakam bulunmalıdır.",
    "Password needs to contain at least one special character." : "Parolada en az bir simge karakteri bulunmalıdır.",
    "Password needs to contain at least one lower and one upper case character." : "Parolada en az bir küçük ve bir büyük harf bulunmalıdır.",
    "Password policy" : "Parola ilkesi",
    "Allows admins to configure a password policy" : "Yöneticilerin bir parola ilkesi yapılandırmasını sağlar",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Yöneticilerin parolalar için en kısa uzunluk gibi çeşitli ön koşullar belirleyebilmesini sağlar.",
    "Saved" : "Kaydedildi",
    "Minimum password length" : "En kısa parola uzunluğu",
    "User password history" : "Kullanıcının parola geçmişi",
    "Number of days until user password expires" : "Kullanıcı parolasının süresinin dolmasına kalan gün",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Kullanıcının hesabı kilitlenmeden önce deneyebileceği oturum açma girişimi sayısı (sınırlama olmaması için 0 yazın)",
    "Forbid common passwords" : "Sık kullanılan parolalar kullanılamasın",
    "Enforce upper and lower case characters" : "Parolada büyük ve küçük harfler bulunsun",
    "Enforce numeric characters" : "Parolada rakam bulunsun",
    "Enforce special characters" : "Parolada simge karakterleri bulunsun",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Parolalar haveibeenpwned.com üzerindeki bilinen parolalar listesi ile denetlensin",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Bu denetim paroladan bir sağlama değeri üretir ve ilk 5 karakterini haveibeenpwned.com API uygulamasına göndererek bu 5 karakter ile başlayan karmaların listesini alır. Ardından Nexctcloud kopyasında parola karmasının sonuç kümesinde olup olmadığını denetler.",
    "Unknown error" : "Bilinmeyen sorun",
    "Minimal length has to be a non negative number" : "En kısa uzunluk negatif bir sayı olamaz",
    "History size has to be a non negative number" : "Geçmiş boyutu negatif bir sayı olamaz",
    "Expiration days have to be a non negative number" : "Geçerlilik süresi negatif bir sayı olamaz",
    "Maximum login attempts have to be a non negative number" : "En fazla oturum açma girişimi sayısı negatif bir sayı olamaz",
    "Error while saving" : "Kaydedilirken sorun çıktı"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-24.0.10.tgz: nextcloud/apps/password_policy/l10n/tr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Parolanın geçerlilik süresi dolmuş. Lütfen sıfırlamak için parolamı unuttum yöntemini kullanın",
    "Password must not have been used recently before." : "Parola son kullandığınız parolalardan farklı olmalıdır.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Yazdığınız parola sık kullanılan 1.000.000 parola içinde. Lütfen eşsiz bir parola seçin.",
    "Password is present in compromised password list. Please choose a different password." : "Yazdığınız parola bilinen parolalar listesinde. Lütfen başka bir parola seçin.",
    "Password needs to be at least %s characters long." : "Parola en az %s karakter uzunluğunda olmalıdır.",
    "Password needs to contain at least one numeric character." : "Parolada en az bir rakam bulunmalıdır.",
    "Password needs to contain at least one special character." : "Parolada en az bir simge karakteri bulunmalıdır.",
    "Password needs to contain at least one lower and one upper case character." : "Parolada en az bir küçük ve bir büyük harf bulunmalıdır.",
    "Password policy" : "Parola ilkesi",
    "Allows admins to configure a password policy" : "Yöneticilerin bir parola ilkesi yapılandırmasını sağlar",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Yöneticilerin parolalar için en kısa uzunluk gibi çeşitli ön koşullar belirleyebilmesini sağlar.",
    "Saved" : "Kaydedildi",
    "Minimum password length" : "En kısa parola uzunluğu",
    "User password history" : "Kullanıcının parola geçmişi",
    "Number of days until user password expires" : "Kullanıcı parolasının geçerlilik süresinin dolmasına kalan gün",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Kullanıcının hesabı kilitlenmeden önce deneyebileceği oturum açma girişimi sayısı (sınırlama olmaması için 0 yazın)",
    "Forbid common passwords" : "Sık kullanılan parolalar kullanılamasın",
    "Enforce upper and lower case characters" : "Parolada büyük ve küçük harfler bulunsun",
    "Enforce numeric characters" : "Parolada rakam bulunsun",
    "Enforce special characters" : "Parolada simge karakterleri bulunsun",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Parolalar haveibeenpwned.com üzerindeki bilinen parolalar listesi ile denetlensin",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Bu denetim paroladan bir sağlama değeri üretir ve ilk 5 karakterini haveibeenpwned.com API uygulamasına göndererek bu 5 karakter ile başlayan karmaların listesini alır. Ardından Nexctcloud kopyasında parola karmasının sonuç kümesinde olup olmadığını denetler.",
    "Unknown error" : "Bilinmeyen sorun",
    "Minimal length has to be a non negative number" : "En kısa uzunluk negatif bir sayı olamaz",
    "History size has to be a non negative number" : "Geçmiş boyutu negatif bir sayı olamaz",
    "Expiration days have to be a non negative number" : "Geçerlilik süresi negatif bir sayı olamaz",
    "Maximum login attempts have to be a non negative number" : "En fazla oturum açma girişimi sayısı negatif bir sayı olamaz",
    "Error while saving" : "Kaydedilirken sorun çıktı"
},
"nplurals=2; plural=(n > 1);");
